﻿using Microsoft.AspNetCore.Hosting;
using Microsoft.EntityFrameworkCore;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;

namespace Aya_Backend.Data.Repositories
{
    public class AyaContext : DbContext
    {
        public DbSet<User> Users { get; set; }
        public DbSet<Workbook> Workbooks { get; set; }
        public DbSet<Workpage> Workpages { get; set; }

        private IHostingEnvironment HostEnv { get; }

        public AyaContext(DbContextOptions<AyaContext> options, IHostingEnvironment env) : base(options)
        {
            HostEnv = env;
        }

        protected override void OnConfiguring(DbContextOptionsBuilder options)
            => options.UseSqlite("Data Source=aya.db");

        protected override void OnModelCreating(ModelBuilder modelBuilder)
        {
            base.OnModelCreating(modelBuilder);

            if (HostEnv != null && HostEnv.IsDevelopment())
            {
                modelBuilder.Entity<User>()
                    .HasData(
                        new User() { ID = 1, Username = "User1", Password = "Password1_" },
                        new User() { ID = 2, Username = "User2", Password = "Password2_" },
                        new User() { ID = 3, Username = "User3", Password = "Password3_" }
                    );

                modelBuilder.Entity<Workbook>()
                    .HasData(
                        new Workbook() { ID = 1, Name = "Workbook 1", OwnerID = 1 },
                        new Workbook() { ID = 2, Name = "Workbook 2", OwnerID = 1 },
                        new Workbook() { ID = 3, Name = "Workbook 3", OwnerID = 2 },
                        new Workbook() { ID = 4, Name = "Workbook 4", OwnerID = 2 },
                        new Workbook() { ID = 5, Name = "Workbook 5", OwnerID = 3 }
                    );

                modelBuilder.Entity<Workpage>()
                    .HasData(
                        new Workpage() { ID = 1, Name = "Workpage 1", WorkbookID = 1, Content = "Content 1" },
                        new Workpage() { ID = 2, Name = "Workpage 2", WorkbookID = 1, Content = "Content 2" },
                        new Workpage() { ID = 3, Name = "Workpage 3", WorkbookID = 1, Content = "Content 3" },
                        new Workpage() { ID = 4, Name = "Workpage 4", WorkbookID = 1, Content = "Content 4" },
                        new Workpage() { ID = 5, Name = "Workpage 5", WorkbookID = 2, Content = "Content 5" },
                        new Workpage() { ID = 6, Name = "Workpage 6", WorkbookID = 2, Content = "Content 6" },
                        new Workpage() { ID = 7, Name = "Workpage 7", WorkbookID = 3, Content = "Content 7" }
                    );
            }
        }
    }
}
