﻿using Microsoft.EntityFrameworkCore;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;

namespace Aya_Backend.Data.Repositories.UserRepositories
{
    public class Repository : IRepository
    {
        private readonly AyaContext _context;

        public Repository(AyaContext context)
        {
            _context = context;
        }

        //User
        public User GetUser(int id)
        {
            return _context.Users.FirstOrDefault(u => u.ID == id);
        }

        public User GetUserAuth(string username, string password)
        {
            return _context.Users.FirstOrDefault(u => u.Username == username && u.Password == password);
        }

        public User AddUser(User user)
        {
            var u = _context.Add(user);
            _context.SaveChanges();
            return u.Entity;
        }
        public void UpdateUser(User user)
        {
            _context.Update(user);
            _context.SaveChanges();
        }

        //Workbook
        public Workbook GetWorkbook(int id)
        {
            return _context.Workbooks.FirstOrDefault(u => u.ID == id);
        }

        public Workbook AddWorkbook(string name, int ownerid)
        {
            var added = _context.Add(new Workbook { Name = name, OwnerID = ownerid });
            _context.SaveChangesAsync();
            return added.Entity;
        }

        public List<Workbook> GetUserWorkbooks(int id)
        {
            return _context.Workbooks.Where(wb => wb.OwnerID == id).ToList();
        }

        //Workpage
        public Workpage GetWorkpage(int id)
        {
            return _context.Workpages.FirstOrDefault(wp => wp.ID == id);
        }

        public void AddWorkpage(Workpage wp)
        {
            _context.Add(wp);
            _context.SaveChanges();
        }

        public List<Workpage> GetWorkbookWorkpages(int id)
        {
            return _context.Workpages.Where(wp => wp.WorkbookID == id).ToList();
        }

        public void UpdateWorkbookContent(int id, string content)
        {
            var original = _context.Workpages.FirstOrDefault(wp => wp.ID == id);

            if (original == null)
                return;

            original.Content = content;
            _context.Update(original);
            _context.SaveChanges();
        }

        public int GetWorkpageOwnerID(int id)
        {
            var workbook = _context.Workpages.Include(wp => wp.Workbook).FirstOrDefault(wp => wp.ID == id);
            return workbook.Workbook.OwnerID;
        }
    }
}
